'use strict';

const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;
const GLib = imports.gi.GLib;
const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

function init() {
}

function buildPrefsWidget() {
	let entries = imports.byteArray.toString(GLib.spawn_command_line_sync("systemctl reboot --boot-loader-entry=help")[1]);
	let settings = ExtensionUtils.getSettings('org.gnome.shell.extensions.net.bgreco.restartinto');
	let currentSecondaryEntry = settings.get_string('entry');

	let prefsWidget = new Gtk.Grid({
		margin: 18,
		column_spacing: 12,
		row_spacing: 12,
		visible: true
	});

	let title = new Gtk.Label({
		label: `<b>${Me.metadata.name} Preferences</b>`,
		halign: Gtk.Align.START,
		use_markup: true,
		visible: true
	});
	prefsWidget.attach(title, 0, 0, 2, 1);

	let entryLabel = new Gtk.Label({
		label: 'Secondary boot menu entry:',
		halign: Gtk.Align.START,
		visible: true
	});
	prefsWidget.attach(entryLabel, 0, 1, 1, 1);

	let entryBox = new Gtk.ComboBoxText({
		halign: Gtk.Align.END,
		visible: true
	});
	for (const [i, entry] of entries.split("\n").entries()) {
		if (entry.trim().length) {
			entryBox.append_text(entry);
			if (entry == currentSecondaryEntry) {
				entryBox.set_active(i);
			}
		}
	}
	entryBox.connect('changed', function (w) {
		settings.set_string('entry', w.get_active_text());
	});
	prefsWidget.attach(entryBox, 1, 1, 1, 1);

	let labelLabel = new Gtk.Label({
		label: 'Secondary restart button label:',
		halign: Gtk.Align.START,
		valign: Gtk.Align.START,
		hexpand: false,
		visible: true,
		"margin-top": 5,
	});
	prefsWidget.attach(labelLabel, 0, 2, 1, 1);

	let labelTextView = new Gtk.TextView({
		buffer: new Gtk.TextBuffer({
			text: settings.get_string('label'),
		}),
		editable: true,
		visible: true,
		"top-margin": 5,
		"bottom-margin": 5,
		"left-margin": 5,
		"right-margin": 5,
		"height-request": 50,
	});
	labelTextView.get_buffer().connect('changed', function (b) {
		settings.set_string('label', b.text);
	});
	prefsWidget.attach(labelTextView, 1, 2, 1, 1);

	prefsWidget.connect('realize', () => {
		let window = prefsWidget.get_toplevel();
		window.resize(100, 100);
	});

	return prefsWidget;
}
